==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01Fluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEChallengeSolverHTTP01Fluent<A extends ACMEChallengeSolverHTTP01Fluent<A>> extends BaseFluent<A>{
  public ACMEChallengeSolverHTTP01Fluent() {
  }
  
  public ACMEChallengeSolverHTTP01Fluent(ACMEChallengeSolverHTTP01 instance) {
    this.copyInstance(instance);
  }
  private ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder gatewayHTTPRoute;
  private ACMEChallengeSolverHTTP01IngressBuilder ingress;
  
  protected void copyInstance(ACMEChallengeSolverHTTP01 instance) {
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01());
  
    if (instance != null) {
        this.withGatewayHTTPRoute(instance.getGatewayHTTPRoute());
        this.withIngress(instance.getIngress());
        this.withGatewayHTTPRoute(instance.getGatewayHTTPRoute());
        this.withIngress(instance.getIngress());
      }
  }
  
  public ACMEChallengeSolverHTTP01GatewayHTTPRoute buildGatewayHTTPRoute() {
    return this.gatewayHTTPRoute!=null ?this.gatewayHTTPRoute.build():null;
  }
  
  public A withGatewayHTTPRoute(ACMEChallengeSolverHTTP01GatewayHTTPRoute gatewayHTTPRoute) {
    _visitables.get("gatewayHTTPRoute").remove(this.gatewayHTTPRoute);
    if (gatewayHTTPRoute!=null){ this.gatewayHTTPRoute= new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(gatewayHTTPRoute); _visitables.get("gatewayHTTPRoute").add(this.gatewayHTTPRoute);} else { this.gatewayHTTPRoute = null; _visitables.get("gatewayHTTPRoute").remove(this.gatewayHTTPRoute); } return (A) this;
  }
  
  public boolean hasGatewayHTTPRoute() {
    return this.gatewayHTTPRoute != null;
  }
  
  public GatewayHTTPRouteNested<A> withNewGatewayHTTPRoute() {
    return new GatewayHTTPRouteNested(null);
  }
  
  public GatewayHTTPRouteNested<A> withNewGatewayHTTPRouteLike(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
    return new GatewayHTTPRouteNested(item);
  }
  
  public GatewayHTTPRouteNested<A> editGatewayHTTPRoute() {
    return withNewGatewayHTTPRouteLike(java.util.Optional.ofNullable(buildGatewayHTTPRoute()).orElse(null));
  }
  
  public GatewayHTTPRouteNested<A> editOrNewGatewayHTTPRoute() {
    return withNewGatewayHTTPRouteLike(java.util.Optional.ofNullable(buildGatewayHTTPRoute()).orElse(new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder().build()));
  }
  
  public GatewayHTTPRouteNested<A> editOrNewGatewayHTTPRouteLike(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
    return withNewGatewayHTTPRouteLike(java.util.Optional.ofNullable(buildGatewayHTTPRoute()).orElse(item));
  }
  
  public ACMEChallengeSolverHTTP01Ingress buildIngress() {
    return this.ingress!=null ?this.ingress.build():null;
  }
  
  public A withIngress(ACMEChallengeSolverHTTP01Ingress ingress) {
    _visitables.get("ingress").remove(this.ingress);
    if (ingress!=null){ this.ingress= new ACMEChallengeSolverHTTP01IngressBuilder(ingress); _visitables.get("ingress").add(this.ingress);} else { this.ingress = null; _visitables.get("ingress").remove(this.ingress); } return (A) this;
  }
  
  public boolean hasIngress() {
    return this.ingress != null;
  }
  
  public IngressNested<A> withNewIngress() {
    return new IngressNested(null);
  }
  
  public IngressNested<A> withNewIngressLike(ACMEChallengeSolverHTTP01Ingress item) {
    return new IngressNested(item);
  }
  
  public IngressNested<A> editIngress() {
    return withNewIngressLike(java.util.Optional.ofNullable(buildIngress()).orElse(null));
  }
  
  public IngressNested<A> editOrNewIngress() {
    return withNewIngressLike(java.util.Optional.ofNullable(buildIngress()).orElse(new ACMEChallengeSolverHTTP01IngressBuilder().build()));
  }
  
  public IngressNested<A> editOrNewIngressLike(ACMEChallengeSolverHTTP01Ingress item) {
    return withNewIngressLike(java.util.Optional.ofNullable(buildIngress()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01Fluent that = (ACMEChallengeSolverHTTP01Fluent) o;
    if (!java.util.Objects.equals(gatewayHTTPRoute, that.gatewayHTTPRoute)) return false;
  
    if (!java.util.Objects.equals(ingress, that.ingress)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(gatewayHTTPRoute,  ingress,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (gatewayHTTPRoute != null) { sb.append("gatewayHTTPRoute:"); sb.append(gatewayHTTPRoute + ","); }
    if (ingress != null) { sb.append("ingress:"); sb.append(ingress); }
    sb.append("}");
    return sb.toString();
  }
  public class GatewayHTTPRouteNested<N> extends ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<GatewayHTTPRouteNested<N>> implements Nested<N>{
    GatewayHTTPRouteNested(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
      this.builder = new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01Fluent.this.withGatewayHTTPRoute(builder.build());
    }
    
    public N endGatewayHTTPRoute() {
      return and();
    }
    
  
  }
  public class IngressNested<N> extends ACMEChallengeSolverHTTP01IngressFluent<IngressNested<N>> implements Nested<N>{
    IngressNested(ACMEChallengeSolverHTTP01Ingress item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01Fluent.this.withIngress(builder.build());
    }
    
    public N endIngress() {
      return and();
    }
    
  
  }

}

==> certmanager-model-v1alpha3-6.9.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01Fluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEChallengeSolverHTTP01Fluent<A extends ACMEChallengeSolverHTTP01Fluent<A>> extends BaseFluent<A>{
  public ACMEChallengeSolverHTTP01Fluent() {
  }
  
  public ACMEChallengeSolverHTTP01Fluent(ACMEChallengeSolverHTTP01 instance) {
    this.copyInstance(instance);
  }
  private ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder gatewayHTTPRoute;
  private ACMEChallengeSolverHTTP01IngressBuilder ingress;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ACMEChallengeSolverHTTP01 instance) {
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01());
    if (instance != null) {
          this.withGatewayHTTPRoute(instance.getGatewayHTTPRoute());
          this.withIngress(instance.getIngress());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public ACMEChallengeSolverHTTP01GatewayHTTPRoute buildGatewayHTTPRoute() {
    return this.gatewayHTTPRoute != null ? this.gatewayHTTPRoute.build() : null;
  }
  
  public A withGatewayHTTPRoute(ACMEChallengeSolverHTTP01GatewayHTTPRoute gatewayHTTPRoute) {
    this._visitables.remove("gatewayHTTPRoute");
    if (gatewayHTTPRoute != null) {
        this.gatewayHTTPRoute = new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(gatewayHTTPRoute);
        this._visitables.get("gatewayHTTPRoute").add(this.gatewayHTTPRoute);
    } else {
        this.gatewayHTTPRoute = null;
        this._visitables.get("gatewayHTTPRoute").remove(this.gatewayHTTPRoute);
    }
    return (A) this;
  }
  
  public boolean hasGatewayHTTPRoute() {
    return this.gatewayHTTPRoute != null;
  }
  
  public GatewayHTTPRouteNested<A> withNewGatewayHTTPRoute() {
    return new GatewayHTTPRouteNested(null);
  }
  
  public GatewayHTTPRouteNested<A> withNewGatewayHTTPRouteLike(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
    return new GatewayHTTPRouteNested(item);
  }
  
  public GatewayHTTPRouteNested<A> editGatewayHTTPRoute() {
    return withNewGatewayHTTPRouteLike(java.util.Optional.ofNullable(buildGatewayHTTPRoute()).orElse(null));
  }
  
  public GatewayHTTPRouteNested<A> editOrNewGatewayHTTPRoute() {
    return withNewGatewayHTTPRouteLike(java.util.Optional.ofNullable(buildGatewayHTTPRoute()).orElse(new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder().build()));
  }
  
  public GatewayHTTPRouteNested<A> editOrNewGatewayHTTPRouteLike(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
    return withNewGatewayHTTPRouteLike(java.util.Optional.ofNullable(buildGatewayHTTPRoute()).orElse(item));
  }
  
  public ACMEChallengeSolverHTTP01Ingress buildIngress() {
    return this.ingress != null ? this.ingress.build() : null;
  }
  
  public A withIngress(ACMEChallengeSolverHTTP01Ingress ingress) {
    this._visitables.remove("ingress");
    if (ingress != null) {
        this.ingress = new ACMEChallengeSolverHTTP01IngressBuilder(ingress);
        this._visitables.get("ingress").add(this.ingress);
    } else {
        this.ingress = null;
        this._visitables.get("ingress").remove(this.ingress);
    }
    return (A) this;
  }
  
  public boolean hasIngress() {
    return this.ingress != null;
  }
  
  public IngressNested<A> withNewIngress() {
    return new IngressNested(null);
  }
  
  public IngressNested<A> withNewIngressLike(ACMEChallengeSolverHTTP01Ingress item) {
    return new IngressNested(item);
  }
  
  public IngressNested<A> editIngress() {
    return withNewIngressLike(java.util.Optional.ofNullable(buildIngress()).orElse(null));
  }
  
  public IngressNested<A> editOrNewIngress() {
    return withNewIngressLike(java.util.Optional.ofNullable(buildIngress()).orElse(new ACMEChallengeSolverHTTP01IngressBuilder().build()));
  }
  
  public IngressNested<A> editOrNewIngressLike(ACMEChallengeSolverHTTP01Ingress item) {
    return withNewIngressLike(java.util.Optional.ofNullable(buildIngress()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01Fluent that = (ACMEChallengeSolverHTTP01Fluent) o;
    if (!java.util.Objects.equals(gatewayHTTPRoute, that.gatewayHTTPRoute)) return false;
    if (!java.util.Objects.equals(ingress, that.ingress)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(gatewayHTTPRoute,  ingress,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (gatewayHTTPRoute != null) { sb.append("gatewayHTTPRoute:"); sb.append(gatewayHTTPRoute + ","); }
    if (ingress != null) { sb.append("ingress:"); sb.append(ingress + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class GatewayHTTPRouteNested<N> extends ACMEChallengeSolverHTTP01GatewayHTTPRouteFluent<GatewayHTTPRouteNested<N>> implements Nested<N>{
    GatewayHTTPRouteNested(ACMEChallengeSolverHTTP01GatewayHTTPRoute item) {
      this.builder = new ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01GatewayHTTPRouteBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01Fluent.this.withGatewayHTTPRoute(builder.build());
    }
    
    public N endGatewayHTTPRoute() {
      return and();
    }
    
  
  }
  public class IngressNested<N> extends ACMEChallengeSolverHTTP01IngressFluent<IngressNested<N>> implements Nested<N>{
    IngressNested(ACMEChallengeSolverHTTP01Ingress item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressBuilder(this, item);
    }
    ACMEChallengeSolverHTTP01IngressBuilder builder;
    
    public N and() {
      return (N) ACMEChallengeSolverHTTP01Fluent.this.withIngress(builder.build());
    }
    
    public N endIngress() {
      return and();
    }
    
  
  }

}
